Package: MetaGxBreast
Type: Package
Title: Transcriptomic Breast Cancer Datasets
Version: 1.33.0
Date: 2020-04-23
Authors@R: c(
    person(
        family='Zon',
        given='Michael',
        role='aut',
        email='michaelzon7@gmail.com'
    ),
    person(
        family='Gendoo',
        given='Deena M.A.',
        role='aut',
        email='deena.gendoo@utoronto.ca'
    ),
    person(
        family='Eeles',
        given='Christopher',
        role='ctb',
        email='christopher.eeles@uhnresearch.ca'
    ),
    person(
        family='Haibe-Kains',
        given='Benjamin',
        role=c('aut', 'cre'),
        email='benjamin.haibe.kains@utoronto.ca'
    ))
Description: A collection of Breast Cancer Transcriptomic Datasets that are 
  part of the MetaGxData package compendium. 
License: Apache License (>= 2)
Depends: R (>= 3.6.0), Biobase, AnnotationHub, ExperimentHub
Imports: stats, lattice, impute, SummarizedExperiment
Suggests: testthat, xtable, tinytex
NeedsCompilation: no
biocViews: ExpressionData, ExperimentHub, CancerData,
        Homo_sapiens_Data, ArrayExpress, GEO, NCI, MicroarrayData,
        ExperimentData
Packaged: 2026-04-30 15:47:07 UTC; biocbuild
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/MetaGxBreast
git_branch: devel
git_last_commit: 8d29f74
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
Author: Michael Zon [aut],
  Deena M.A. Gendoo [aut],
  Christopher Eeles [ctb],
  Benjamin Haibe-Kains [aut, cre]
Maintainer: Benjamin Haibe-Kains <benjamin.haibe.kains@utoronto.ca>
