
#No processing has been applied to the gene expression data for the datasets. They have been left in the form they were obtained.
#In the case of the GEO files the expression data would generally be in the form obtained after converting the results
#from the microarray platform to gene expression values. In the NCI dataset that was taken from the supplementary files of the paper,
#the dataset would be processed in whatever manner the authors of the paper described.
